/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */

/* 
 * Copyright (C) 2002 James Willcox
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Author: James Willcox <jwillcox@gnome.org>
 */

#include <config.h>
#include "nautilus-music-properties-view.h"

#include <bonobo/bonobo-i18n.h>
#include <gtk/gtkentry.h>
#include <gtk/gtkvbox.h>
#include <glade/glade-xml.h>
#include <libgnome/gnome-macros.h>
#include <monkey-media/monkey-media.h>
#include <monkey-media/monkey-media-stream-info.h>
#include <eel/eel-gnome-extensions.h>
#include <string.h>

struct NautilusMusicPropertiesViewDetails {
	char *location;
	GtkWidget *vbox;
	GtkWidget *title;
	GtkWidget *artist;
	GtkWidget *album;
};

BONOBO_CLASS_BOILERPLATE (NautilusMusicPropertiesView, nautilus_music_properties_view,
			  NautilusView, NAUTILUS_TYPE_VIEW)

static void
nautilus_music_properties_view_finalize (GObject *object)
{
	NautilusMusicPropertiesView *view;
	
	view = NAUTILUS_MUSIC_PROPERTIES_VIEW (object);
	
	g_free (view->details->location);
	g_free (view->details);

	G_OBJECT_CLASS (object)->finalize (object);
}

static void
load_location (NautilusMusicPropertiesView *view,
	       const char *location)
{
	MonkeyMediaStreamInfo *info;
	GValue val = { 0, };

	g_assert (NAUTILUS_IS_MUSIC_PROPERTIES_VIEW (view));
	g_assert (location != NULL);
	
	if (view->details->location) {
		g_free (view->details->location);
	}

	view->details->location = g_strdup (location);

	info = monkey_media_stream_info_new (location, NULL);

	monkey_media_stream_info_get_value (info,
			MONKEY_MEDIA_STREAM_INFO_FIELD_TITLE,
			0, &val);
	gtk_entry_set_text (GTK_ENTRY (view->details->title),
			    g_value_get_string (&val));

	monkey_media_stream_info_get_value (info,
			MONKEY_MEDIA_STREAM_INFO_FIELD_ARTIST,
			0, &val);
	gtk_entry_set_text (GTK_ENTRY (view->details->artist),
			    g_value_get_string (&val));

	monkey_media_stream_info_get_value (info,
			MONKEY_MEDIA_STREAM_INFO_FIELD_ALBUM,
			0, &val);
	gtk_entry_set_text (GTK_ENTRY (view->details->album),
			    g_value_get_string (&val));
	
}

static void
sample_load_location_callback (NautilusView *nautilus_view, 
			       const char *location,
			       gpointer user_data)
{
	NautilusMusicPropertiesView *view;
	
	g_assert (NAUTILUS_IS_VIEW (nautilus_view));
	g_assert (location != NULL);
	
	view = NAUTILUS_MUSIC_PROPERTIES_VIEW (nautilus_view);
	
	nautilus_view_report_load_underway (nautilus_view);
	
	/* Do the actual load. */
	load_location (view, location);
	
	nautilus_view_report_load_complete (nautilus_view);
}

static void
nautilus_music_properties_view_class_init (NautilusMusicPropertiesViewClass *class)
{
	G_OBJECT_CLASS (class)->finalize = nautilus_music_properties_view_finalize;
}

static void
nautilus_music_properties_view_instance_init (NautilusMusicPropertiesView *view)
{
	GladeXML *xml;

	monkey_media_init (NULL, NULL);

	view->details = g_new0 (NautilusMusicPropertiesViewDetails, 1);

	xml = glade_xml_new (DATADIR "/nautilus/glade/nautilus-music-properties-view.glade", "content", NULL);

	g_return_if_fail (xml != NULL);
	
	view->details->vbox = glade_xml_get_widget (xml, "content");
	view->details->title = glade_xml_get_widget (xml, "title");
	view->details->artist = glade_xml_get_widget (xml, "artist");
	view->details->album = glade_xml_get_widget (xml, "album");
	view->details->location = NULL;

	gtk_entry_set_text (GTK_ENTRY (view->details->title), "Unknown");
	gtk_entry_set_text (GTK_ENTRY (view->details->artist), "Unknown");
	gtk_entry_set_text (GTK_ENTRY (view->details->album), "Unknown");
	
	gtk_widget_show_all (view->details->vbox);
	
	nautilus_view_construct (NAUTILUS_VIEW (view), view->details->vbox);
	
	g_signal_connect (view, "load_location",
			  G_CALLBACK (sample_load_location_callback), NULL);

}
